pub trait QueryStrategy<IR, OR = IR> {
// Required method
fn process(&mut self, peer_id: PeerId, response: IR) -> QueryStep<OR>;
}Expand description
Fedimint query strategy
Due to federated security model each Fedimint client API call to the Federation might require a different way to process one or more required responses from the Federation members. This trait abstracts away the details of each specific strategy for the generic client Api code.
Required Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".